@@ -28,11 +28,11 @@
 
 /**
 	*Contains all relevant information for specifying an observing
-	*location on Earth: City Name, State/Country Name, Longitude,
-	*Latitude, and Time Zone.
+	*location on Earth: City Name, State/Province name, Country Name,
+	*Longitude, Latitude, and Time Zone.
 	*@short Relevant data about an observing location on Earth.
 	*@author Jason Harris
-	*@version 0.4
+	*@version 0.9
 	*/
 
 class GeoLocation {
@@ -41,16 +41,22 @@ public:
 	*Default constructor; sets coordinates to zero.	
 	*/
 	GeoLocation();
+
 /**
 	*Copy Constructor
 	*/	
 	GeoLocation( const GeoLocation &g );
+
+/**
+	*Copy Constructor.  Differs from the above function only in argument type.
+	*/	
 	GeoLocation( GeoLocation *g );
+
 /**
 	*Constructor using dms objects to specify longitude and latitude.
 	*/
-	
 	GeoLocation( dms lng, dms lat, QString name="Nowhere", QString province="Nowhere", QString country="Nowhere", double TZ=0 );
+
 /**
 	*Constructor using doubles to specify longitude and latitude.
 	*/
@@ -61,41 +67,41 @@ public:
 	~GeoLocation() {};
 
 /**
-	*Returns longitude
+	*@returns longitude
 	*/	
 	dms lng() const { return Longitude; }
 /**
-	*Returns latitude
+	*@returns latitude
 	*/
 	dms lat() const { return Latitude; }
 /**
-	*Return untranslated City name
+	*@returns untranslated City name
 	*/
 	QString name() const { return Name; }
 
 /**
-	*Return translated City name
+	*@returns translated City name
 	*/
-	QString translatedName() const { return i18n(Name.utf8().data()); }
+	QString translatedName() const { return i18n(Name.local8Bit().data()); }
 /**
-	*Return untranslated Province name
+	*@returns untranslated Province name
 	*/
 	QString province() const { return Province; }
 
 /**
-	*Return translated City name
+	*@returns translated Province name
 	*/
-	QString translatedProvince() const { return i18n(Province.utf8().data()); }
+	QString translatedProvince() const { return i18n(Province.local8Bit().data()); }
 /**
-	*Return untranslated State/Country name
+	*@returns untranslated Country name
 	*/
 	QString country() const { return Country; }
 /**
-	*Return translated State/Country name
+	*@returns translated Country name
 	*/
-	QString translatedCountry() const { return i18n(Country.utf8().data()); }
+	QString translatedCountry() const { return i18n(Country.local8Bit().data()); }
 /**
-	*Return time zone
+	*@returns time zone
 	*/
 	double TZ() const { return TimeZone; }
 
@@ -103,36 +109,44 @@ public:
 	*Set longitude according to argument.
 	*/
 	void setLong( dms l ) { Longitude = l; }
+
 /**
 	*Set longitude according to argument.
 	*Differs from above function only in argument type.
 	*/
 	void setLong( double l ) { Longitude.setD( l ); }
+
 /**
 	*Set latitude according to argument.
 	*/
 	void setLat( dms l ) { Latitude  = l; }
+
 /**
 	*Set latitude according to argument.
 	*Differs from above function only in argument type.
 	*/
 	void setLat( double l ) { Latitude.setD( l ); }
+
 /**
 	*Set City name according to argument.
 	*/
 	void setName( const QString &n ) { Name = n; }
+
 /**
-	*Set City name according to argument.
+	*Set Province name according to argument.
 	*/
 	void setProvince( const QString &n ) { Province = n; }
+
 /**
-	*Set State/Country name according to argument.
+	*Set Country name according to argument.
 	*/
 	void setCountry( const QString &s ) { Country = s; }
+
 /**
 	*Sets Time Zone according to argument.
 	*/
 	void setTZ( double tz ) { TimeZone = tz; }
+
 /**
 	*Set location data to that of the GeoLocation pointed to by argument.
 	*Similar to copy constructor.
