@@ -30,15 +30,19 @@
 
 KStarsSplash::KStarsSplash( KStarsData* kstarsData, QWidget *parent, const char* name, bool modal )
 		: KDialogBase( KDialogBase::Plain, i18n( "Loading KStars..." ),
-			0 /*no buttons please*/, Ok, parent ) {
+			0 /*no buttons*/, Ok, parent ) {
+
+	//Set up widgets for splashscreen.
 	QFrame *page = plainPage();
 	page->setBackgroundColor( QColor( "Black" ) );
 	setBackgroundColor( QColor( "Black" ) );
 
-	this->kstarsData = kstarsData;
-  QVBoxLayout *topLayout = new QVBoxLayout( page, 0, 0 );//spacingHint() );
-	topLayout->setMargin( 0 ); //still have an ugly margin :(
+  QVBoxLayout *topLayout = new QVBoxLayout( page, 0, 0 );
+	topLayout->setMargin( 0 );
 	
+	this->kstarsData = kstarsData;
+
+	//Load the KStars banner.  Use an empty image if it can't be opened.
 	QFile imFile;
 	if ( kstarsData->openDataFile( imFile, "kstars.png" ) ) {
 		imFile.close(); //Just need the filename...
@@ -52,6 +56,7 @@ KStarsSplash::KStarsSplash( KStarsData* kstarsData, QWidget *parent, const char*
 	Banner->setFixedHeight( splashImage->height() );
 	topLayout->addWidget( Banner );
 	
+	//initialize the "Welcome to KStars message label
   QLabel *label = new QLabel( page, "label1" );
 	QPalette pal( label->palette() );
 	pal.setColor( QPalette::Normal, QColorGroup::Background, QColor( "Black" ) );
@@ -59,12 +64,10 @@ KStarsSplash::KStarsSplash( KStarsData* kstarsData, QWidget *parent, const char*
 	pal.setColor( QPalette::Inactive, QColorGroup::Foreground, QColor( "White" ) );
   label->setPalette( pal );
 	label->setAlignment( AlignHCenter );
-  label->setText( i18n( "Welcome to KStars. Please standby while loading..." ) );
+  label->setText( i18n( "Welcome to KStars. Please stand by while loading..." ) );
   topLayout->addWidget( label );
 
-  //
-  // It is very simple to add a new label here
-  //
+  //initialize the progress message label
   textCurrentStatus = new QLabel( page, "label2" );
   textCurrentStatus->setPalette( pal );
 	textCurrentStatus->setAlignment( AlignHCenter );
@@ -77,10 +80,10 @@ KStarsSplash::KStarsSplash( KStarsData* kstarsData, QWidget *parent, const char*
 	// Otherwise the labels won't display.                 	
 	loadStatus = 0;
   qtimer = new QTimer();
-
 	connect ( qtimer, SIGNAL (timeout()), this, SLOT( slotLoadDataFile() ) );
-	// special timer: fire when message queue is empty. Ideal for long jobs
-	// see QT documentation of class QTimer;
+
+	// The timer has a zero interval; it fires when the message queue is empty.
+	// This is ideal for long jobs; see QT documentation of class QTimer...
   qtimer->start(0); 	
 }
 
@@ -104,7 +107,9 @@ void KStarsSplash::slotLoadDataFile()
 	
 	switch (loadStatus)
 	{
-	case 2:
+
+	case 2: //Load Cities//
+
 		if ( !kstarsData->readCityData( ) ) {
 			qtimer->stop();
 			KludgeError( "Cities.dat" );
@@ -112,7 +117,9 @@ void KStarsSplash::slotLoadDataFile()
 		}
 	  textCurrentStatus->setText( i18n("Loading star data" ) ); // next load, show text now
 		break;
-	case 4:
+
+	case 4: //Load SAO stellar database//
+
 		if ( !kstarsData->readStarData( ) ) {
 			qtimer->stop();
 			KludgeError( "sao.dat" );
@@ -120,7 +127,9 @@ void KStarsSplash::slotLoadDataFile()
 		}
 	  textCurrentStatus->setText( i18n("Loading NGC data" ) ); // next load, show text now
 		break;
-	case 6:
+
+	case 6: //Load NGC 2000 database//
+
 		if ( !kstarsData->readNGCData( ) ) {
 			qtimer->stop();
 			KludgeError( "ngc2000.dat" );
@@ -128,15 +137,19 @@ void KStarsSplash::slotLoadDataFile()
 		}
 	  textCurrentStatus->setText( i18n("Loading constellations" ) ); // next load, show text now
 		break;
-	case 8:
+
+	case 8: //Load Constellation lines//
+
 		if ( !kstarsData->readCLineData( ) ) {
 			qtimer->stop();
 			KludgeError( "clines.dat" );
 			reject();
 		}
-	  textCurrentStatus->setText( i18n("Loading constellations names" ) ); // next load, show text now
+	  textCurrentStatus->setText( i18n("Loading constellation names" ) ); // next load, show text now
 		break;
-	case 10:
+
+	case 10: //Load Constellation names//
+
 		if ( !kstarsData->readCNameData( ) ) {
 			qtimer->stop();
 			KludgeError( kstarsData->cnameFile );
@@ -144,7 +157,9 @@ void KStarsSplash::slotLoadDataFile()
 		}
 	  textCurrentStatus->setText( i18n("Loading Milky Way" ) ); // next load, show text now
 		break;
-	case 12:
+
+	case 12: //Load Milky Way//
+
 		if ( !kstarsData->readMWData( ) ) {
 			qtimer->stop();
 			KludgeError( "mw*.dat" );
@@ -152,43 +167,50 @@ void KStarsSplash::slotLoadDataFile()
 		}
 	  textCurrentStatus->setText( i18n("Starting Clock" ) ); // next load, show text now
 		break;
-	case 14:
-		//start the clock
-		//"now" and "then" always refer to current system clock.	
-		//LTime and UTime represent the current simulation time.
-		//For now, initialize LTime to system clock; perhaps it should remember
-		//the time of the last session (unless the time was the current time,
-		//in that case, the user may want the current time this session as well...)
-		kstarsData->now   = QDateTime::currentDateTime();
-		kstarsData->then  = kstarsData->now;
-		kstarsData->LTime = kstarsData->now;	
-		kstarsData->UTime = kstarsData->now; //delay timezone offset to KStars constructor
-		kstarsData->CurrentDate = kstarsData->getJD( kstarsData->UTime );
-		kstarsData->LastPlanetUpdate = kstarsData->CurrentDate;
-		kstarsData->LastMoonUpdate   = kstarsData->CurrentDate;
+
+	case 14: //Start the Clock//
+
+		//Minimal initialization of time/date, necessary for initializing the planets
+		kstarsData->CurrentDate = kstarsData->getJD( QDateTime::currentDateTime() );
+
+		//The Sky is updated more frequently than the moon, which is updated more frequently
+		//than the planets.  The date of the last update for each category is recorded so we
+		//know when we need to do it again (see KStars::updateTime()).
+		//Initializing these to the current date - 1 ensures they will be updated immediately
+		//on the first call to KStars::updateTime().
+		kstarsData->LastSkyUpdate = kstarsData->CurrentDate-1.0;
+		kstarsData->LastPlanetUpdate = kstarsData->CurrentDate-1.0;
+		kstarsData->LastMoonUpdate   = kstarsData->CurrentDate-1.0;
+
 	  textCurrentStatus->setText( i18n("Creating Sun" ) ); // next load, show text now
 		break;
-	case 16:
+
+	case 16: //Initialize the Sun//
+
 		kstarsData->Sun = new KSSun( kstarsData->CurrentDate );
 		ImageName = "sun.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Sun->image.load( imFile.name() );
+			kstarsData->Sun->image()->load( imFile.name() );
 		}
 
 		kstarsData->objList->append( kstarsData->Sun );
-		kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Sun->name, kstarsData->objList->current()));
+		kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Sun->name(), kstarsData->objList->current()));
 	  textCurrentStatus->setText( i18n("Creating Moon" ) ); // next load, show text now
 		break;
-	case 18:
+
+	case 18: //Initialize the Moon//
+
 		kstarsData->Moon = new KSMoon( kstarsData->CurrentDate );
 		kstarsData->Moon->findPhase( kstarsData->Sun );
 		kstarsData->objList->append( kstarsData->Moon );
-		kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Moon->name, kstarsData->objList->current()));
+		kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Moon->name(), kstarsData->objList->current()));
 
 	  textCurrentStatus->setText( i18n("Creating Earth" ) ); // next load, show text now
 		break;
-	case 20:
+
+	case 20: //Initialize Earth//
+
 		//Earth is only needed for calculating Geocentric coordinates of planets;
 		//it is not displayed in the skymap, so there is no image, and we
 		//don't add it to objList/ObjNames
@@ -197,126 +219,143 @@ void KStarsSplash::slotLoadDataFile()
 
 	  textCurrentStatus->setText( i18n( "Creating Mercury" ) ); // next load, show text now
 		break;
-	case 22:		
+
+	case 22: //Initialize Mercury//
+
 		kstarsData->Mercury = new KSPlanet( I18N_NOOP( "Mercury" ) );
 		ImageName = "mercury.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Mercury->image.load( imFile.name() );
+			kstarsData->Mercury->image()->load( imFile.name() );
 		}
 		
 		if ( kstarsData->Mercury->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Mercury );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Mercury->name, kstarsData->objList->current()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Mercury->name(), kstarsData->objList->current()));
 		}
 
 	  textCurrentStatus->setText( i18n( "Creating Venus" ) ); // next load, show text now
 		break;
-	case 24:
+
+	case 24: //Initialize Venus//
+
 		kstarsData->Venus = new KSPlanet( I18N_NOOP( "Venus" ) );
 		ImageName = "venus.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Venus->image.load( imFile.name() );
+			kstarsData->Venus->image()->load( imFile.name() );
 		}
 
 		if ( kstarsData->Venus->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Venus );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Venus->name, kstarsData->objList->last()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Venus->name(), kstarsData->objList->last()));
 		}
 
 	  textCurrentStatus->setText( i18n("Creating Mars" ) ); // next load, show text now
 		break;
-	case 26:
+
+	case 26: //Initialize Mars//
+
 		kstarsData->Mars = new KSPlanet( I18N_NOOP( "Mars" ) );
 		ImageName = "mars.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Mars->image.load( imFile.name() );
+			kstarsData->Mars->image()->load( imFile.name() );
 		}
 
 		if ( kstarsData->Mars->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Mars );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Mars->name, kstarsData->objList->last()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Mars->name(), kstarsData->objList->last()));
 		}
 
 	  textCurrentStatus->setText( i18n("Creating Jupiter" ) ); // next load, show text now
 		break;
-	case 28:
+
+	case 28: //Initialize Jupiter//
+
 		kstarsData->Jupiter = new KSPlanet( I18N_NOOP( "Jupiter" ) );
 		ImageName = "jupiter.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Jupiter->image.load( imFile.name() );
+			kstarsData->Jupiter->image()->load( imFile.name() );
 		}
 		
 		if ( kstarsData->Jupiter->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Jupiter );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Jupiter->name, kstarsData->objList->last()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Jupiter->name(), kstarsData->objList->last()));
     }
 
 	  textCurrentStatus->setText( i18n("Creating Saturn" ) ); // next load, show text now
 		break;
-	case 30:	
+
+	case 30:	//Initialize Saturn//
+
 		kstarsData->Saturn = new KSPlanet( I18N_NOOP( "Saturn" ) );
 		ImageName = "saturn.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Saturn->image.load( imFile.name() );
+			kstarsData->Saturn->image()->load( imFile.name() );
 		}
 		
 		if ( kstarsData->Saturn->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Saturn );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Saturn->name, kstarsData->objList->last()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Saturn->name(), kstarsData->objList->last()));
     }
 
 	  textCurrentStatus->setText( i18n("Creating Uranus" ) ); // next load, show text now
 		break;
-	case 32:
+
+	case 32: //Initialize Uranus//
+
 		kstarsData->Uranus = new KSPlanet( I18N_NOOP( "Uranus" ) );
 		ImageName = "uranus.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Uranus->image.load( imFile.name() );
+			kstarsData->Uranus->image()->load( imFile.name() );
 		}
 		
 		if ( kstarsData->Uranus->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Uranus );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Uranus->name, kstarsData->objList->last()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Uranus->name(), kstarsData->objList->last()));
     }
 
 	  textCurrentStatus->setText( i18n("Creating Neptune" ) ); // next load, show text now
 		break;
-	case 34:			
+
+	case 34: //Initialize Neptune//
+
 		kstarsData->Neptune = new KSPlanet( I18N_NOOP( "Neptune" ) );
 		ImageName = "neptune.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Neptune->image.load( imFile.name() );
+			kstarsData->Neptune->image()->load( imFile.name() );
 		}
 		
 		if ( kstarsData->Neptune->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Neptune );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Neptune->name, kstarsData->objList->last()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Neptune->name(), kstarsData->objList->last()));
 		}
 	  textCurrentStatus->setText( i18n("Creating Pluto" ) ); // next load, show text now
 		break;
-	case 36:			
+
+	case 36: //Initialize Pluto//
+
 		kstarsData->Pluto = new KSPluto();
 		ImageName = "pluto.png";
 		if ( KStarsData::openDataFile( imFile, ImageName ) ) {
 			imFile.close();
-			kstarsData->Pluto->image.load( imFile.name() );
+			kstarsData->Pluto->image()->load( imFile.name() );
 		}
 		
 		if ( kstarsData->Pluto->findPosition( kstarsData->CurrentDate, kstarsData->Earth ) ) {
 			kstarsData->objList->append( kstarsData->Pluto );
-			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Pluto->name, kstarsData->objList->last()));
+			kstarsData->ObjNames->append( new SkyObjectName (kstarsData->Pluto->name(), kstarsData->objList->last()));
 		}
 	  textCurrentStatus->setText( i18n("Loading Image URLs" ) ); // next load, show text now
 		break;
 
-	case 38:
+	case 38: //Load Image URLs//
+
 		if ( !kstarsData->readURLData( "image_url.dat", 0 ) ) {
 			qtimer->stop();
 			KludgeError( "image_url.dat", false );
@@ -327,7 +366,9 @@ void KStarsSplash::slotLoadDataFile()
 		}
 	  textCurrentStatus->setText( i18n("Loading Information URLs" ) ); // next load, show text now
 		break;
-	case 40:
+
+	case 40: //Load Information URLs//
+
 		if ( !kstarsData->readURLData( "info_url.dat", 1 ) ) {
 			qtimer->stop();
 			KludgeError( "info_url.dat", false );
@@ -357,7 +398,7 @@ void KStarsSplash::KludgeError( QString s, bool required ) {
 					i18n( "Place it in one of the following locations, then try again:" ) + "\n\n" +
 					(QString)"\t$(KDEDIR)/share/apps/kstars/" + s +
 					(QString)"\n\t~/.kde/share/apps/kstars/" + s +
-					(QString)"\n\t$(PATH_TO_KSTARS)/data/" + s;
+					(QString)"\n\t[KSTARS_SOURCE_DIR]/data/" + s;
 		QString caption = i18n( "Critical file not found: " ) + s;
   } else {
 			message = i18n( "The file " ) + s + i18n( " could not be found." )+ "\n" +
@@ -366,7 +407,7 @@ void KStarsSplash::KludgeError( QString s, bool required ) {
 				i18n( "place the file in one of the following locations:" ) + "\n\n" +
 				(QString)"\t$(KDEDIR)/share/apps/kstars/" + s +
 				(QString)"\n\t~/.kde/share/apps/kstars/" + s +
-				(QString)"\n\t$(PATH_TO_KSTARS)/data/" + s;
+				(QString)"\n\t[KSTARS_SOURCE_DIR]/data/" + s;
 			caption = i18n( "Non-critical file not found: " ) + s;
 	}
 	
