@@ -19,21 +19,21 @@
 #include "dms.h"
 
 SkyObject::SkyObject(){
-	type = 0;
+	Type = 0;
 	Position.set( 0.0, 0.0 );
-  mag = 0.0;
-  name = "unnamed";
-  name2 = "";
-  longname = "";
+  Magnitude = 0.0;
+  Name = "unnamed";
+  Name2 = "";
+  LongName = "";
 }
 
 SkyObject::SkyObject( SkyObject &o ) {
-	type = o.type;
+	Type = o.type();
 	Position = *o.pos();
-  mag = o.mag;
-  name = o.name;
-	name2 = o.name2;
-	longname = o.longname;
+  Magnitude = o.mag();
+  Name = o.name();
+	Name2 = o.name2();
+	LongName = o.longname();
 	ImageList = o.ImageList;
 	ImageTitle = o.ImageTitle;
 	InfoList = o.InfoList;
@@ -42,61 +42,61 @@ SkyObject::SkyObject( SkyObject &o ) {
 
 SkyObject::SkyObject( int t, dms r, dms d, double m, QString n,
                       QString n2, QString lname ) {
-  type = t;
+	Type = t;
 	Position.setRA0( r );
 	Position.setDec0( d );
 	Position.setRA( r );
 	Position.setDec( d );
-  mag = m;
-  name = n;
-  name2 = n2;
-  longname = lname;
+  Magnitude = m;
+  Name = n;
+  Name2 = n2;
+  LongName = lname;
 }
 
 SkyObject::SkyObject( int t, double r, double d, double m, QString n,
                       QString n2, QString lname ) {
-  type = t;
+	Type = t;
 	Position.setRA0( r );
 	Position.setDec0( d );
 	Position.setRA( r );
 	Position.setDec( d );
-  mag = m;
-  name = n;
-  name2 = n2;
-  longname = lname;
+  Magnitude = m;
+  Name = n;
+  Name2 = n2;
+  LongName = lname;
 }
 
 QTime SkyObject::riseTime( long double jd, GeoLocation *geo ) {
-	double r = -1.0 * tan( geo->lat().radians() ) * tan( getDec().radians() );
+	double r = -1.0 * tan( geo->lat().radians() ) * tan( dec().radians() );
 	if ( r < -1.0 || r > 1.0 )
 		return QTime( 25, 0, 0 );  //this object does not rise or set; return an invalid time
 		
 	double H = acos( r )*180./acos(-1.0); //180/Pi converts radians to degrees
 	dms LST;
-	LST.setH( 24.0 + getRA().getH() - H/15.0 );
+	LST.setH( 24.0 + ra().Hours() - H/15.0 );
 	LST = LST.reduce();
 
 	//convert LST to Greenwich ST
-	dms GST = dms( LST.getD() - geo->lng().getD() ).reduce();
+	dms GST = dms( LST.Degrees() - geo->lng().Degrees() ).reduce();
 
 	//convert GST to UT
 	double T = ( jd - J2000 )/36525.0;
 	dms T0, dT, UT;
 	T0.setH( 6.697374558 + (2400.051336*T) + (0.000025862*T*T) );
 	T0 = T0.reduce();
-	dT.setH( GST.getH() - T0.getH() );
+	dT.setH( GST.Hours() - T0.Hours() );
 	dT = dT.reduce();
-	UT.setH( 0.9972695663 * dT.getH() );
+	UT.setH( 0.9972695663 * dT.Hours() );
 	UT = UT.reduce();
 
 	//convert UT to LT;
-	dms LT = dms( UT.getD() + 15.0*geo->TZ() ).reduce();
+	dms LT = dms( UT.Degrees() + 15.0*geo->TZ() ).reduce();
 
-	return QTime( LT.getHour(), LT.getHMin(), LT.getHSec() );
+	return QTime( LT.hour(), LT.minute(), LT.second() );
 }
 
 QTime SkyObject::setTime( long double jd, GeoLocation *geo ) {
-	double r = -1.0 * tan( geo->lat().radians() ) * tan( getDec().radians() );
+	double r = -1.0 * tan( geo->lat().radians() ) * tan( dec().radians() );
 	if ( r < -1.0 || r > 1.0 )
 		return QTime( 25, 0, 0 );  //this object does not rise or set; return an invalid time
 		
@@ -104,23 +104,23 @@ QTime SkyObject::setTime( long double jd, GeoLocation *geo ) {
 	dms LST;
 
 	//the following line is the only difference between riseTime() and setTime()
-	LST.setH( getRA().getH() + H/15.0 );
+	LST.setH( ra().Hours() + H/15.0 );
 	LST = LST.reduce();
 
 	//convert LST to Greenwich ST
-	dms GST = dms( LST.getD() - geo->lng().getD() ).reduce();
+	dms GST = dms( LST.Degrees() - geo->lng().Degrees() ).reduce();
 
 	//convert GST to UT
 	double T = ( jd - J2000 )/36525.0;
 	dms T0, dT, UT;
 	T0.setH( 6.697374558 + (2400.051336*T) + (0.000025862*T*T) );
 	T0 = T0.reduce();
-	dT.setH( GST.getH() - T0.getH() );
+	dT.setH( GST.Hours() - T0.Hours() );
 	dT = dT.reduce();
-	UT.setH( 0.9972695663 * dT.getH() );
+	UT.setH( 0.9972695663 * dT.Hours() );
   UT = UT.reduce();
 
 	//convert UT to LT;
-	dms LT = dms( UT.getD() + 15.0*geo->TZ() ).reduce();
-	return QTime( LT.getHour(), LT.getHMin(), LT.getHSec() );
+	dms LT = dms( UT.Degrees() + 15.0*geo->TZ() ).reduce();
+	return QTime( LT.hour(), LT.minute(), LT.second() );
 }
