@@ -24,20 +24,32 @@
 
 #include "skyobject.h"
 
-/**
-  *@author Thomas Kabelmann
-  */
+/**Convenience class which contains a SkyObject's name and a pointer to the SkyObject
+	*itself.  This class is used to construct the List of named objects that may be
+	*located with the FindDialog.
+	*@short convenience class for indexing SkyObjects by name.
+	*@author Thomas Kabelmann
+	*@version 0.9
+	*/
 
 class SkyObjectName {
 	
 	public:
+	/**Constructor*/
 		SkyObjectName (const QString &str = QString::null, SkyObject *obj = 0);
-		~SkyObjectName();
 
+	/**Destructor (empty)*/
+		~SkyObjectName() {}
+
+	/**@returns the name of the SkyObject*/
 		QString text() { return Text; }
-		QString translatedText() { return i18n( Text.utf8().data()); }
+
+	/**@returns translated version of the SkyObject's name*/
+		QString translatedText() { return i18n( Text.local8Bit().data()); }
+
+	/**@returns pointer to the SkyObject*/
 		SkyObject *skyObject() { return skyobject; }
-		
+
 	private:
 	
 		SkyObject *skyobject;
@@ -45,12 +57,27 @@ class SkyObjectName {
 };
 
 
+/**Class for filling list of named objects in the Find Object dialog (FindDialog).
+	*The class is derived from QListBoxText, and adds a SkyObjectName* member variable,
+	*and a method to retrieve this variable (a pointer).  This makes it very easy
+	*to add these items to the FindDialog's QListBox, and to sort and filter them.
+	*@short Derivative of QListBoxItem specifically for SkyObjects
+	*@author Thomas Kabelmann
+	*@version 0.9
+	*/
+
 class SkyObjectNameListItem : public QListBoxText  {
 	
 	public:
+	/**Constructor.  Pass useLatinConstellationNames to determine if name() or translatedName()
+		*should be used for constellations.
+		*/
 		SkyObjectNameListItem (QListBox *parent, SkyObjectName *name, bool useLatinConstellNames = true);
-		~SkyObjectNameListItem();
 
+	/**Destructor (empty)*/
+		~SkyObjectNameListItem() {}
+
+	/**@returns pointer to SkyObjectName associated with this SkyObjectNameListItem */
 		SkyObjectName * objName() { return object; }
 		
 	private:
